@@ -1,12 +1,19 @@
 use std::{
     env,
+    io::stdout,
     path::{Path, PathBuf},
 };
 
 use cli::app::app;
 use git2::{Config, Repository};
-use miette::{GraphicalTheme, IntoDiagnostic, Result};
-use mit_commit_message_lints::external::Git2;
+use miette::{IntoDiagnostic, Result};
+use mit_commit_message_lints::{
+    console::{
+        completion::{print_completions, Shell},
+        error_handling::miette_install,
+    },
+    external::Git2,
+};
 use mit_lint::Lint;
 
 use crate::errors::{
@@ -19,21 +26,18 @@ mod cmd;
 mod errors;
 
 fn main() -> Result<()> {
-    if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
-        miette::set_hook(Box::new(|_| {
-            Box::new(
-                miette::MietteHandlerOpts::new()
-                    .force_graphical(true)
-                    .terminal_links(false)
-                    .graphical_theme(GraphicalTheme::unicode_nocolor())
-                    .build(),
-            )
-        }))
-        .unwrap();
-    }
+    miette_install();
 
     let lint_names: Vec<&str> = Lint::all_lints().map(Lint::name).collect();
-    let matches = app(&lint_names).get_matches();
+    let mut app = app(&lint_names);
+    let matches = app.clone().get_matches();
+
+    // Simply print and exit if completion option is given.
+    if let Ok(completion) = matches.value_of_t::<Shell>("completion") {
+        print_completions(&mut stdout(), &mut app, completion);
+
+        std::process::exit(0);
+    }
 
     let possible: Option<Result<()>> = [
         cmd::author_example::run_on_match,
